@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -484,12 +483,16 @@ void
 dlg_properties (GooWindow *window)
 {
 	DialogData *data;
+	GtkWidget *image;
+	gboolean rtl;
 
         if (window->properties_dialog != NULL) {
         	gtk_window_present (GTK_WINDOW (window->properties_dialog));
         	return;
         }
 
+        rtl = gtk_widget_get_direction (GTK_WIDGET (window)) == GTK_TEXT_DIR_RTL;
+
 	data = g_new0 (DialogData, 1);
 	data->window = window;
 	data->builder = _gtk_builder_new_from_resource ("properties.ui");
@@ -502,6 +505,15 @@ dlg_properties (GooWindow *window)
 	data->dialog = GET_WIDGET ("properties_dialog");
 	window->properties_dialog = data->dialog;
 
+	image = GET_WIDGET ("prev_album_image");
+	gtk_image_set_from_icon_name (GTK_IMAGE (image),
+				      rtl ? "go-previous-rtl-symbolic" : "go-previous-symbolic",
+				      GTK_ICON_SIZE_MENU);
+	image = GET_WIDGET ("next_album_image");
+	gtk_image_set_from_icon_name (GTK_IMAGE (image),
+				      rtl ? "go-next-rtl-symbolic" : "go-next-symbolic",
+				      GTK_ICON_SIZE_MENU);
+
 	/* Set widgets data. */
 
 	data->list_store = gtk_list_store_new (N_COLUMNS,
